@@ -263,6 +263,8 @@ def recall(cm, mode:str='both'):
     Recall:  What fraction of ground truth labels was correct?
     Given a confusion matrix, recall divides the diagonal by the row sums.
 
+    Memory aid: Think  Recall --> Rows.  Both start with R.
+
     For example, given a binary confusion matrix, we have:
 
         Positive class recall (aka sensitivity):
@@ -272,7 +274,7 @@ def recall(cm, mode:str='both'):
             sensitivity = recall_pos = TP / (TP + FN)
 
         Negative class recall (aka specificity)
-            specificity = recall_neg = TP / (TP + FN)
+            specificity = recall_neg = TN / (TN + FP)
 
     Args:
         cm: Binary confusion matrix like this:
