@@ -98,7 +98,28 @@ def _get_all_data(ns):
     return cdfs
 
 
-def make_plots(ns, cdfs):
+def _get_subplots(N:int):
+    if N < 5:
+        M = 1
+    else:
+        M = int(np.sqrt(N))
+        N = int(np.ceil(N/M))
+    fig, axs = plt.subplots(N, M, figsize=(12,10), squeeze=False, sharex=True,
+                            sharey=True)
+    return fig, axs
+
+
+def _subplots_add_legend(fig, handles_labels):
+    print(handles_labels)
+    fig.tight_layout()
+    fig.subplots_adjust(bottom=0.1)
+    # choose just one axis as the legend, since they are all identical
+    fig.legend(*handles_labels,
+               loc='lower center', bbox_to_anchor=(0.5, -0.0),
+               fancybox=False, shadow=False, ncol=3)
+
+
+def make_plots(ns, cdfs, subplots:bool):
     cols = [col for col in cdfs.columns if re.search(ns.col_regex, col)]
     if ns.avg_cols:
         colname = 'Mean(%s)' % ns.col_regex
@@ -109,8 +130,13 @@ def make_plots(ns, cdfs):
     cdfs = cdfs.copy()
     cdfs.columns = [prettify(x) for x in cdfs.columns]
     cdfs.index.names = [prettify(x) for x in cdfs.index.names]
-    for col in plot_cols:
-        fig, ax = plt.subplots(1,1)
+    if subplots:
+        fig, axs = _get_subplots(len(plot_cols))
+    for n, col in enumerate(plot_cols):
+        if subplots:
+            ax = axs.ravel()[n]
+        else:
+            fig, ax = plt.subplots(1,1)
         df = cdfs[col].unstack(level=0)
         if ns.rolling_mean:
             df = df.rolling(ns.rolling_mean).mean()
@@ -118,12 +144,18 @@ def make_plots(ns, cdfs):
             print('WARNING: skip col with no numeric data:', col)
             ax.set_title(f'{col}, SKIPPED because no numeric data')
             continue
-        _plot_lines = df.plot(ax=ax, title=col, legend=ns.legend, alpha=.9)
+        _plot_lines = df.plot(
+            ax=ax, title=col, legend=None if subplots else ns.legend, alpha=.9)
         #  _legend = mpld3.plugins.InteractiveLegendPlugin(
             #  *_plot_lines.get_legend_handles_labels())
         #  mpld3.plugins.connect(fig, _legend)
 
-        yield (fig, ax, col)
+        if not subplots:
+            yield (fig, col)
+    if subplots:
+        if ns.legend:
+            _subplots_add_legend(fig, ax.get_legend_handles_labels())
+        yield (fig, col)
 
 
 def savefig_with_symlink(fig, fp, symlink_fp):
@@ -185,7 +217,13 @@ def mode_1_plots(ns):
 
     timestamp = dt.datetime.utcnow().strftime('%Y%m%dT%H%M%S.%f')  # date plot was created.  nothing to do with timestamp column.
     os.makedirs(join(ns.mode1_savefig_dir, 'archive'), exist_ok=True)
-    for fig, ax, col in make_plots(ns, cdfs):
+    for fig, col in make_plots(ns, cdfs, ns.mode1_subplots):
+        if ns.savefig and ns.mode1_subplots:
+            # would need, I think, to make each column a subfigure instead of
+            # axes plot.
+            warnings.warn(
+                "Sorry, but --mode1-subplots and --savefig haven't been made"
+                " to work nicely together yet.")
         if not ns.savefig: continue
         savefig_with_symlink(
             fig,
@@ -216,7 +254,7 @@ def mode_2_plots(ns):
         cdfs_mode2[run_id] = cdfs
 
         os.makedirs(f'{ns.mode2_savefig_dir}/archive'.format(run_id=run_id), exist_ok=True)
-        for fig, ax, col in make_plots(ns, cdfs.reset_index('run_id', drop=True)):
+        for fig, col in make_plots(ns, cdfs.reset_index('run_id', drop=True), False):
             fig.suptitle(run_id)
             if not ns.savefig: continue
             # save to file
@@ -306,13 +344,7 @@ def _mode4_make_subplots(grp:pd.DataFrame, ns):
                 ' more columns (see previously printed msgs)')
     assert len(colgrps) > 0, 'code bug'
     # choose nrows, ncols for the figure
-    N = len(set(colgrps))
-    if N < 5:
-        M = 1
-    else:
-        M = int(np.sqrt(N))
-        N = int(np.ceil(N/M))
-    fig, axs = plt.subplots(N, M, figsize=(12,10), squeeze=False)
+    fig, axs = _get_subplots(N=len(set(colgrps)))
     colgrps = np.array(colgrps)
     for ax, subplot_title in zip(axs.ravel(), sorted(set(colgrps))):
         cols = grp.columns[colgrps == subplot_title]
@@ -334,8 +366,17 @@ def _mode4_make_subplots(grp:pd.DataFrame, ns):
             continue
         z.plot(ax=ax, title=subplot_title)
         print(ns)
-        if not ns.legend:
-            ax.get_legend().remove()
+        if ns.legend:
+            _handles, _labels = ax.get_legend_handles_labels()
+        ax.get_legend().remove()
+        #  if not ns.legend:
+            #  ax.get_legend().remove()
+    if ns.legend:
+        # note: the legend labels may be incorrect if --mode4-groupby is not
+        # default value.
+        _subplots_add_legend(
+            fig, (_handles, [re.search(regex, x).group(1) for x in _labels]))
+
     fig.suptitle(f'Experiment: {run_id}')
     fig.tight_layout()
     if ns.savefig:
@@ -396,6 +437,8 @@ def bap():
     A('--mode4-savefig-dir', default='./results/plots/mode4', help=' ')
     A('--mode3-ci', type=float,
       help='confidence interval for error bars.  If 0, also shows all lines individually')
+    A('--mode1-subplots', action='store_true', help=dedent('''\
+        If defined, generate subplots instead of figures.'''))
     A('--mode4-groupby', default="(Train|Val|Test) (.*):2", help=dedent('''\
         Optionally, make one sub-plot for each group of columns. To use, pass a
         regular expression extracting a string that we can group related
