@@ -555,9 +555,8 @@ class MultiClassClassification(Result):
     @property
     def metrics(self):
         metrics = ('Loss', 'Num Samples', 'MCC', 'Acc', 'BAcc', 'cm')
-        if self._cm.shape[0] == 2:
+        if self.num_classes.shape[0] == 2:
             metrics += ('Precision', 'Recall', 'F1', )
-            # exclude these since we haven't determined if micro or macro avg or other
         return metrics
 
     def __init__(self, num_classes:int,
@@ -592,15 +591,15 @@ class MultiClassClassification(Result):
 
     @property
     def f1(self):
-        return metrics.f1_score(self._cm).item()
+        return metrics.f1_score(self._cm, mode='pos').item()
 
     @property
     def precision(self):
-        return metrics.precision(self._cm).item()
+        return metrics.precision(self._cm, 'pos').item()
 
     @property
     def recall(self):
-        return metrics.recall(self._cm).item()
+        return metrics.recall(self._cm, 'pos').item()
 
     @property
     def cm(self):
@@ -676,15 +675,17 @@ class MultiLabelBinaryClassification(Result):
 
     @property
     def f1(self):
-        return self._on_each_cm('F1 {class_name}', metrics.f1_score)
+        return self._on_each_cm('F1 {class_name}', lambda x: metrics.f1_score(x, mode='pos'))
 
     @property
     def precision(self):
-        return self._on_each_cm('Precision {class_name}', metrics.precision)
+        return self._on_each_cm(
+            'Precision {class_name}', lambda x: metrics.precision(x, 'pos'))
 
     @property
     def recall(self):
-        return self._on_each_cm('Recall {class_name}', metrics.recall)
+        return self._on_each_cm(
+            'Recall {class_name}', lambda x: metrics.recall(x, 'pos'))
 
     @property
     def cm(self):
